@@ -1,6 +1,20 @@
 #item.py
 #Copyright (C) 2005 Free Software Foundation
-#see GPL.txt for license.
+#This file is part of Dragon Hunt.
+
+#Dragon Hunt is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
+
+#Dragon Hunt is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+
+#You should have received a copy of the GNU General Public License
+#along with Dragon Hunt; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #This file contains the item/inv structures and functions.
 
@@ -18,6 +32,8 @@ class item_class:
 		self.quality = 0
 		#If price is 0, the item is un sell/buy/drop able. (For story items.)
 		self.price = 0
+		# value is how much you can sell it for, vs. price is the cost to buy
+		self.value = 0
 		self.description = ""
 		self.picturename = "items/dropped.png"
 		self.hp_bonus = 0
@@ -113,11 +129,21 @@ def additem(item_filename):
 	temp_type = 0
 	temp_quality = 0
 	temp_price = 0
+	temp_value = 0
 	temp_description = ""
 	temp_picture = None
 	item.append(item_class())
 	item_array_loc = len(item)-1
 
+	# default values
+	item[item_array_loc].name = ""
+	item[item_array_loc].type = 0
+	item[item_array_loc].quality = 0
+	item[item_array_loc].price = 0
+	item[item_array_loc].value = 0
+	item[item_array_loc].description = ""
+	item[item_array_loc].picturename = None
+
 	item_file = g.read_script_file("/data/items/" + item_filename)
 
 	#go through all lines of the file
@@ -136,6 +162,8 @@ def additem(item_filename):
 			item[item_array_loc].quality = int(item_line.split("=", 1)[1])
 		elif (item_command.lower() == "price"):
 			item[item_array_loc].price = int(item_line.split("=", 1)[1])
+		elif (item_command.lower() == "value"):
+			item[item_array_loc].value = int(item_line.split("=", 1)[1])
 		elif (item_command.lower() == "description"):
 			item[item_array_loc].description = str(item_line.split("=", 1)[1])
 		elif (item_command.lower() == "picture"):
@@ -149,6 +177,8 @@ def additem(item_filename):
 		elif (item_command.lower() == "defense_bonus"):
 			item[item_array_loc].defense_bonus = int(item_line.split("=", 1)[1])
 
+	if (item[item_array_loc].value == 0):
+		item[item_array_loc].value = item[item_array_loc].price
 
 #An array of dropped items. Used for keeping dropped items around
 #through save/loads.
@@ -175,4 +205,4 @@ def load_dropped_items():
 	for dropped_item in dropped_items:
 		z = g.mapname2zgrid(dropped_item.mapname)
 		g.maps[z].field[dropped_item.y][dropped_item.x].additem(
-														dropped_item.name)
\ No newline at end of file
+														dropped_item.name)
