@@ -1,6 +1,20 @@
 #file: scripting.py
 #Copyright (C) 2005 Free Software Foundation
-#see GPL.txt for license.
+#This file is part of Dragon Hunt.
+
+#Dragon Hunt is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
+
+#Dragon Hunt is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+
+#You should have received a copy of the GNU General Public License
+#along with Dragon Hunt; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #This file controls the loading of datafiles.
 
@@ -258,6 +272,7 @@ class shop_item:
 		self.item_name = name
 		itemnum = g.item.finditem(name)
 		self.cost = 0
+		self.value = 0
 		self.buytype = "gold"
 		self.power = 0
 		self.description = ""
@@ -266,6 +281,7 @@ class shop_item:
 		#if adding an actual item, initialize to the item's qualities.
 		if (itemnum != -1):
 			self.cost = g.item.item[itemnum].price
+			self.value = g.item.item[itemnum].value
 			self.buytype = "gold"
 			self.power = g.item.item[itemnum].quality
 			self.description = g.item.item[itemnum].description
@@ -273,6 +289,8 @@ class shop_item:
 
 	def add_cost(self, itemcost):
 		self.cost = itemcost
+	def add_value(self, itemvalue):
+		self.value = itemvalue
 	def add_buytype(self, itembuytype):
 		self.buytype = itembuytype
 	def add_power(self, itempower):
@@ -295,6 +313,8 @@ class shop:
 		self.curitem += 1
 	def item_add_cost(self, itemcost):
 		self.itemlist[self.curitem].add_cost(itemcost)
+	def item_add_value(self, itemvalue):
+		self.itemlist[self.curitem].add_value(itemvalue)
 	def item_add_buytype(self, itembuytype):
 		self.itemlist[self.curitem].add_buytype(itembuytype)
 	def item_add_power(self, itempower):
@@ -339,6 +359,8 @@ def read_shops():
 				shops[cur_shop].item_add_description(command[1].strip())
 			elif (command[0].strip().lower() == "cost"):
 				shops[cur_shop].item_add_cost(command[1].strip().lower())
+			elif (command[0].strip().lower() == "value"):
+				shops[cur_shop].item_add_value(command[1].strip().lower())
 			elif (command[0].strip().lower() == "buytype"):
 				shops[cur_shop].item_add_buytype(command[1].strip().lower())
 			elif (command[0].strip().lower() == "power"):
