@@ -1,6 +1,20 @@
 #file: shop.py
 #Copyright (C) 2005 Free Software Foundation
-#see GPL.txt for license.
+#This file is part of Dragon Hunt.
+
+#Dragon Hunt is free software; you can redistribute it and/or modify
+#it under the terms of the GNU General Public License as published by
+#the Free Software Foundation; either version 2 of the License, or
+#(at your option) any later version.
+
+#Dragon Hunt is distributed in the hope that it will be useful,
+#but WITHOUT ANY WARRANTY; without even the implied warranty of
+#MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+#GNU General Public License for more details.
+
+#You should have received a copy of the GNU General Public License
+#along with Dragon Hunt; if not, write to the Free Software
+#Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #This file controls the town shops.
 
@@ -45,6 +59,7 @@ sell_height=0
 #variables for the middle info display
 item_name  = StringVar()
 item_cost  = StringVar()
+item_value = StringVar()
 item_power = StringVar()
 item_desc  = StringVar()
 curr_gold  = StringVar()
@@ -100,10 +115,18 @@ def refresh_inv():
 	main.recalc_stats()
 
 #Actually sets the info in the middle of the shop screen.
-def set_details(name, cost, costtype, power, description):
+def set_details(name, cost, value, costtype, power, description, inv_or_shop):
 	item_name.set(name)
-	if cost != "": item_cost.set("Cost: " + str(cost) + " " + costtype)
-	else: item_cost.set("")
+	if inv_or_shop == "shop":
+	   	if cost != "":
+			item_cost.set("Cost: " + str(cost) + " " + costtype)
+			item_value.set("")
+	   	else: item_cost.set("")
+	elif inv_or_shop == "inv":
+	   	if value != "":
+			item_value.set("Value: " + str(value) + " " + costtype)
+			item_cost.set("")
+	   	else: item_value.set("")
 	if power == "" or power == "-1": item_power.set("")
 	else: item_power.set("Power: " + str(power))
 	canvas_desc.delete("all")
@@ -119,18 +142,23 @@ def show_details(event=0, sel_item=-1):
 		if sel_item < len(item.inv):
 			if item.inv[sel_item] != -1:
 				tempitem = item.item[item.inv[sel_item]]
-				set_details(tempitem.name, tempitem.price, "gold",
-									tempitem.quality, tempitem.description)
+				if (tempitem.type == 14 and
+					g.shops[store_num].name == "a Gem Shop"):
+					set_details(tempitem.name, tempitem.price, tempitem.price, "gold",
+									tempitem.quality, tempitem.description, "inv")
+				else:
+					set_details(tempitem.name, tempitem.price, tempitem.value, "gold",
+									tempitem.quality, tempitem.description, "inv")
 		#if there is no item selected, blank details.
-			else: set_details("", "", "", "", "")
-		else: set_details("", "", "", "", "")
+			else: set_details("", "", "", "", "", "", "inv")
+		else: set_details("", "", "", "", "", "", "inv")
 
 	else:  #shop
 		if sel_item < len(g.shops[store_num].itemlist):
 			tempitem = g.shops[store_num].itemlist[sel_item]
-			set_details(tempitem.item_name, tempitem.cost, tempitem.buytype,
-										tempitem.power, tempitem.description)
-		else: set_details("", "", "", "", "")
+			set_details(tempitem.item_name, tempitem.cost, tempitem.value, tempitem.buytype,
+										tempitem.power, tempitem.description, "shop")
+		else: set_details("", "", "", "", "", "", "shop")
 
 #place appropriate items into the store.
 def refresh_shop():
@@ -171,9 +199,18 @@ def sell_item():
 	#note that all stores have a 5 year, money-back guarantee,
 	#and accept returns from other stores as well.
 	#This means there is no need to doublecheck intent. ;)
+	#FIXME: this is no longer true since gems aren't paid for
+	#full value anywhere but the gem shop
+	#print g.shops[store_num].name
+	if (item.item[item.inv[curr_item]].type == 14 and
+		        g.shops[store_num].name == "a Gem Shop"):
+		main.print_message("The Gem Shop owner is happy to pay the true value of your gems.")
+		g.gold = int(g.gold) + item.item[item.inv[curr_item]].price
+	else:
+	   	g.gold = int(g.gold) + item.item[item.inv[curr_item]].value
+
 	main.print_message("You sell your " + item.item[item.inv[curr_item]].name
 		+ ".")
-	g.gold = int(g.gold) + item.item[item.inv[curr_item]].price
 
 	#remove the item
 	item.drop_inv_item(curr_item)
@@ -413,6 +450,8 @@ def init_window_shop(store_type_input):
 		wraplength=143, bg=bgcolour).grid(row=8, column=3, sticky=W)
 	label_cost = Label(window_shop,
 		textvar=item_cost, bg=bgcolour).grid(row=9, column=3, sticky=W)
+	label_value = Label(window_shop,
+		textvar=item_value, bg=bgcolour).grid(row=9, column=3, sticky=W)
 	label_power = Label(window_shop,
 		textvar=item_power, bg=bgcolour).grid(row=11, column=3, sticky=W)
 
